@@ -2,6 +2,7 @@ from .request import RequestTask, RequestTaskHandlers, RequestTaskResponse
 from .wait import WaitTask
 from .print import PrintTask
 from .transformer import TransformerTask
+from .until import UntilRequestTask
 
 __all__ = [
     'RequestTaskHandlers',
@@ -10,4 +11,5 @@ __all__ = [
     'PrintTask',
     'WaitTask',
     'TransformerTask',
+    'UntilRequestTask',
 ]
