@@ -2,28 +2,73 @@ import logging
 import sys
 
 from abc import ABC, abstractmethod
-from typing import Optional, Dict, Any, TypedDict, Callable, cast
+from typing import Optional, Dict, Any, TypedDict, Callable, List, cast
 from os import environ, path
 from platform import node as hostname
 from json import dumps as jsondumps
 from time import monotonic as time
 from io import StringIO
+from threading import Lock
+from datetime import datetime
 
 from grizzly_extras.transformer import JsonBytesEncoder
 
-__all__ = [
-    'AsyncMessageContext',
-    'AsyncMessageMetadata',
-    'AsyncMessagePayload',
-    'AsyncMessageRequest',
-    'AsyncMessageResponse',
-    'AsyncMessageError',
-]
+__all__: List[str] = []
 
 
 AsyncMessageMetadata = Optional[Dict[str, Any]]
 AsyncMessagePayload = Optional[Any]
 
+class ThreadLogger:
+    _logger: logging.Logger
+    _lock: Lock = Lock()
+
+    _destination: Optional[str] = None
+
+    def __init__(self, name: str) -> None:
+        with self._lock:
+            logger = logging.getLogger(name)
+            log_format = '[%(asctime)s] %(levelname)-5s: %(name)s: %(message)s'
+            formatter = logging.Formatter(log_format)
+            level = logging.getLevelName(environ.get('GRIZZLY_EXTRAS_LOGLEVEL', 'INFO'))
+            logger.setLevel(level)
+            logger.handlers = []
+            stdout_handler = logging.StreamHandler(sys.stderr)
+            stdout_handler.setFormatter(formatter)
+            logger.addHandler(stdout_handler)
+
+            root_logger = logging.getLogger()
+            root_logger.setLevel(logging.NOTSET)  # root logger needs to have lower or equal log level
+            root_logger.handlers = []
+            root_logger.addHandler(logging.StreamHandler(StringIO()))  # disable messages from root logger
+
+            grizzly_context_root = environ.get('GRIZZLY_CONTEXT_ROOT', None)
+
+            if grizzly_context_root is not None:
+                if ThreadLogger._destination is None:
+                    ThreadLogger._destination = f'async-messaged.{hostname()}.{datetime.now().strftime("%Y%m%dT%H%M%S%f")}.log'
+                file_handler = logging.FileHandler(path.join(grizzly_context_root, 'logs', ThreadLogger._destination))
+                file_handler.setFormatter(formatter)
+                logger.addHandler(file_handler)
+
+            self._logger = logger
+
+    def _log(self, level: int, message: str, exc_info: Optional[bool] = False) -> None:
+        with self._lock:
+            self._logger.log(level, message, exc_info=exc_info)
+
+    def debug(self, message: str) -> None:
+        self._log(logging.DEBUG, message)
+
+    def info(self, message: str) -> None:
+        self._log(logging.INFO, message)
+
+    def error(self, message: str, exc_info: Optional[bool] = False) -> None:
+        self._log(logging.ERROR, message, exc_info=exc_info)
+
+    def warning(self, message: str) -> None:
+        self._log(logging.WARNING, message)
+
 class AsyncMessageContext(TypedDict, total=False):
     url: str
     queue_manager: str
@@ -63,10 +108,16 @@ class AsyncMessageError(Exception):
 class AsyncMessageHandler(ABC):
     worker: str
     message_wait: Optional[int]
+    logger: ThreadLogger
 
     def __init__(self, worker: str) -> None:
         self.worker = worker
         self.message_wait = None
+        self.logger = ThreadLogger(f'handler::{worker}')
+
+        # silence uamqp loggers
+        for uamqp_logger_name in ['uamqp', 'uamqp.c_uamqp']:
+            logging.getLogger(uamqp_logger_name).setLevel(logging.ERROR)
 
     @abstractmethod
     def get_handler(self, action: str) -> Optional['AsyncMessageRequestHandler']:
@@ -75,8 +126,7 @@ class AsyncMessageHandler(ABC):
     def handle(self, request: AsyncMessageRequest) -> AsyncMessageResponse:
         action = request['action']
         request_handler = self.get_handler(action)
-        logger.debug(f'{self.worker}: handling {action}')
-        logger.debug(f'{self.worker}: {jsondumps(request, indent=2, cls=JsonBytesEncoder)}')
+        self.logger.debug(f'handling {action}, request=\n{jsondumps(request, indent=2, cls=JsonBytesEncoder)}')
 
         response: AsyncMessageResponse
 
@@ -93,7 +143,7 @@ class AsyncMessageHandler(ABC):
                 'success': False,
                 'message': f'{action}: {e.__class__.__name__}="{str(e)}"',
             }
-            logger.error(f'{self.worker}: {action}: {e.__class__.__name__}="{str(e)}"', exc_info=True)
+            self.logger.error(f'{self.worker}: {action}: {e.__class__.__name__}="{str(e)}"', exc_info=True)
         finally:
             total_time = int((time() - start_time) * 1000)
             response.update({
@@ -101,8 +151,7 @@ class AsyncMessageHandler(ABC):
                 'response_time': total_time,
             })
 
-            logger.debug(f'{self.worker}: handled {action}')
-            logger.debug(f'{self.worker}: {jsondumps(response, indent=2, cls=JsonBytesEncoder)}')
+            self.logger.debug(f'handled {action}, response=\n{jsondumps(response, indent=2, cls=JsonBytesEncoder)}')
 
             return response
 
@@ -129,31 +178,3 @@ def register(handlers: Dict[str, AsyncMessageRequestHandler], action: str, *acti
         return func
 
     return decorator
-
-def configure_logger(name: str) -> logging.Logger:
-    logger = logging.getLogger(name)
-    log_format = '[%(asctime)s] %(levelname)-5s: %(name)s: %(message)s'
-    formatter = logging.Formatter(log_format)
-    level = logging.getLevelName(environ.get('GRIZZLY_EXTRAS_LOGLEVEL', 'INFO'))
-    logger.setLevel(level)
-    logger.handlers = []
-    stdout_handler = logging.StreamHandler(sys.stderr)
-    stdout_handler.setFormatter(formatter)
-    logger.addHandler(stdout_handler)
-
-    root_logger = logging.getLogger()
-    root_logger.setLevel(logging.NOTSET)  # root logger needs to have lower or equal log level
-    root_logger.handlers = []
-    root_logger.addHandler(logging.StreamHandler(StringIO()))  # disable messages from root logger
-
-    if level < logging.INFO:
-        file_name = f'async-messaged.{hostname()}.log'
-        file_handler = logging.FileHandler(path.join(environ.get('GRIZZLY_CONTEXT_ROOT', '.'), 'logs', file_name))
-        file_handler.setFormatter(formatter)
-        logger.addHandler(file_handler)
-
-    logger.info(f'level={logging.getLevelName(level)}')
-
-    return logger
-
-logger = configure_logger(__name__)
